@@ -42,11 +42,14 @@
 #' tryLog(log("a"))  # logs an error
 #' @export
 tryLog <- function(expr,
-                   write.error.dump.file   = getOption("tryCatchLog.write.error.dump.file", FALSE),
-                   write.error.dump.folder = getOption("tryCatchLog.write.error.dump.folder", "."),
-                   silent.warnings         = getOption("tryCatchLog.silent.warnings", FALSE),
-                   silent.messages         = getOption("tryCatchLog.silent.messages", FALSE))
-{
+                   write.error.dump.file      = getOption("tryCatchLog.write.error.dump.file", FALSE),
+                   write.error.dump.folder    = getOption("tryCatchLog.write.error.dump.folder", "."),
+                   silent.warnings            = getOption("tryCatchLog.silent.warnings", FALSE),
+                   silent.messages            = getOption("tryCatchLog.silent.messages", FALSE),
+                   include.full.call.stack    = getOption("tryCatchLog.include.full.call.stack", TRUE),
+                   include.compact.call.stack = getOption("tryCatchLog.include.compact.call.stack", TRUE)
+                   ) {
+
   tryCatchLog(expr = expr,
               write.error.dump.file = write.error.dump.file,
               write.error.dump.folder = write.error.dump.folder,
@@ -55,5 +58,7 @@ tryLog <- function(expr,
                 invisible(structure(msg, class = "try-error", condition = e))
               },
               silent.warnings = silent.warnings,
-              silent.messages = silent.messages)
+              silent.messages = silent.messages,
+              include.full.call.stack = include.full.call.stack,
+              include.compact.call.stack = include.compact.call.stack)
 }
